@@ -1,5 +1,4 @@
-/*
- * Copyright 2003 - 2016, The libsigc++ Development Team
+/* Copyright 2003 - 2016, The libsigc++ Development Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -12,8 +11,7 @@
  *  Lesser General Public License for more details.
  *
  *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ *  License along with this library; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef SIGC_FUNCTORS_MEM_FUN_H
@@ -22,6 +20,7 @@
 #include <sigc++/limit_reference.h>
 #include <sigc++/member_method_trait.h>
 #include <functional>
+#include <utility>
 
 // implementation notes:
 //  - we do not use bind here, because it would introduce
@@ -32,20 +31,17 @@ namespace sigc
 {
 
 /** @defgroup mem_fun mem_fun()
- * mem_fun() Creates a functor from a pointer to a method.
+ * %mem_fun() creates a functor from a pointer to a method.
  *
- * Optionally, a reference or pointer to an object can be bound to the functor.
+ * Optionally, a reference to an object can be bound to the functor.
  *
  * @note If the object type inherits from sigc::trackable, and the
- * functor returned from mem_fun() is assigned to a sigc::slot, the functor
+ * functor returned from %mem_fun() is assigned to
+ * a @ref sigc::slot<T_return(T_arg...)> "sigc::slot", the functor
  * will be automatically cleared when the object goes out of scope. Invoking
  * that slot will then have no effect and will not try to use the destroyed
  * instance.
  *
- * If the member function pointer is to an overloaded type, you must specify
- * the types using template arguments starting with the first argument.
- * It is not necessary to supply the return type.
- *
  * @par Example:
  * @code
  * struct foo : public sigc::trackable
@@ -58,7 +54,7 @@ namespace sigc
  * auto f = sigc::mem_fun(my_foo, &foo::bar); // Usually not what you want.
  * @endcode
  *
- * For const methods mem_fun() takes a const reference or pointer to an object.
+ * For const methods %mem_fun() takes a const reference or pointer to an object.
  *
  * @par Example:
  * @code
@@ -70,18 +66,19 @@ namespace sigc
  * sigc::slot<void(int)> sl = sigc::mem_fun(my_foo, &foo::bar);
  * @endcode
  *
- * Use mem_fun#() if there is an ambiguity as to the number of arguments.
+ * If the member function pointer is to an overloaded type, you must specify
+ * the types using template arguments.
  *
  * @par Example:
  * @code
  * struct foo : public sigc::trackable
  * {
- *   void bar(int) {}
+ *   void bar(int) {} // choose this one
  *   void bar(float) {}
  *   void bar(int, int) {}
  * };
  * foo my_foo;
- * sigc::slot<void(int)> sl = sigc::mem_fun1<int>(my_foo, &foo::bar);
+ * sigc::slot<void(int)> sl = sigc::mem_fun1<void, foo, foo, int>(my_foo, &foo::bar);
  * @endcode
  *
  * @ingroup sigcfunctors
@@ -113,7 +110,7 @@ public:
    */
   decltype(auto) operator()(obj_type_with_modifier& obj, type_trait_take_t<T_arg>... a) const
   {
-    return std::invoke(func_ptr_, obj, a...);
+    return std::invoke(func_ptr_, obj, std::forward<type_trait_take_t<T_arg>>(a)...);
   }
 
 protected:
@@ -149,7 +146,8 @@ public:
    */
   decltype(auto) operator()(type_trait_take_t<T_arg>... a) const
   {
-    return std::invoke(this->func_ptr_, obj_.invoke(), a...);
+    return std::invoke(
+      this->func_ptr_, obj_.invoke(), std::forward<type_trait_take_t<T_arg>>(a)...);
   }
 
   // protected:
