@@ -1,5 +1,4 @@
-/*
- * Copyright 2002 - 2016, The libsigc++ Development Team
+/* Copyright 2002 - 2016, The libsigc++ Development Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -12,9 +11,7 @@
  *  Lesser General Public License for more details.
  *
  *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
+ *  License along with this library; if not, see <https://www.gnu.org/licenses/>.
  */
 #ifndef SIGC_TRACKABLE_HPP
 #define SIGC_TRACKABLE_HPP
@@ -125,11 +122,11 @@ struct SIGC_API trackable : public notifiable
 
   trackable(const trackable& src) noexcept;
 
-  trackable(trackable&& src);
+  trackable(trackable&& src) noexcept;
 
   trackable& operator=(const trackable& src);
 
-  trackable& operator=(trackable&& src);
+  trackable& operator=(trackable&& src) noexcept;
 
   ~trackable();
 
