@@ -11,8 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * License along with this library; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef SIGC_TUPLE_UTILS_TUPLE_FOR_EACH_H
@@ -29,10 +28,10 @@ namespace internal
 namespace detail
 {
 
-template <template <typename> class T_visitor, std::size_t size_from_index, typename... T_extras>
+template<template<typename> class T_visitor, std::size_t size_from_index, typename... T_extras>
 struct tuple_for_each_impl
 {
-  template <typename T>
+  template<typename T>
   constexpr static void tuple_for_each(T&& t, T_extras&&... extras)
   {
     // We use std::decay_t<> because tuple_size is not defined for references.
@@ -50,10 +49,10 @@ struct tuple_for_each_impl
   }
 };
 
-template <template <typename> class T_visitor, typename... T_extras>
+template<template<typename> class T_visitor, typename... T_extras>
 struct tuple_for_each_impl<T_visitor, 1, T_extras...>
 {
-  template <typename T>
+  template<typename T>
   constexpr static void tuple_for_each(T&& t, T_extras&&... extras)
   {
     // We use std::decay_t<> because tuple_size is not defined for references.
@@ -69,10 +68,10 @@ struct tuple_for_each_impl<T_visitor, 1, T_extras...>
   }
 };
 
-template <template <typename> class T_visitor, typename... T_extras>
+template<template<typename> class T_visitor, typename... T_extras>
 struct tuple_for_each_impl<T_visitor, 0, T_extras...>
 {
-  template <typename T>
+  template<typename T>
   constexpr static void tuple_for_each(T&& /* t */, T_extras&&... /* extras */)
   {
     // Do nothing because the tuple has no elements.
@@ -92,20 +91,23 @@ struct tuple_for_each_impl<T_visitor, 0, T_extras...>
  * @param t The tuple whose elements should be visited.
  * @param extras Any extra arguments to pass to @e T_Visitor's visit() method.
  */
-template <template <typename> class T_visitor, typename T, typename... T_extras>
+template<template<typename> class T_visitor, typename T, typename... T_extras>
 constexpr void
 tuple_for_each(T&& t, T_extras&&... extras)
 {
   // We use std::decay_t<> because tuple_size is not defined for references.
   constexpr auto size = std::tuple_size<std::decay_t<T>>::value;
 
-  if (size == 0)
+  if constexpr (size != 0)
   {
-    return;
+    detail::tuple_for_each_impl<T_visitor, size, T_extras...>::tuple_for_each(
+      std::forward<T>(t), std::forward<T_extras>(extras)...);
+  }
+  else
+  {
+    // Prevent 'unreferenced formal parameter' warning from MSVC by 'using' t
+    static_cast<void>(t);
   }
-
-  detail::tuple_for_each_impl<T_visitor, size, T_extras...>::tuple_for_each(
-    std::forward<T>(t), std::forward<T_extras>(extras)...);
 }
 
 } // namespace internal
