@@ -1,5 +1,4 @@
-/*
- * Copyright 2002 - 2016, The libsigc++ Development Team
+/* Copyright 2002 - 2016, The libsigc++ Development Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -12,8 +11,7 @@
  *  Lesser General Public License for more details.
  *
  *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ *  License along with this library; if not, see <https://www.gnu.org/licenses/>.
  */
 #ifndef SIGC_VISIT_EACH_HPP
 #define SIGC_VISIT_EACH_HPP
@@ -32,21 +30,27 @@ struct trackable;
 namespace internal
 {
 
-template <typename Base, typename Derived>
+template<typename Base, typename Derived>
 constexpr bool is_base_of_or_same_v =
   std::is_base_of<std::decay_t<Base>, std::decay_t<Derived>>::value ||
-    std::is_same<std::decay_t<Base>, std::decay_t<Derived>>::value;
+  std::is_same<std::decay_t<Base>, std::decay_t<Derived>>::value;
 
 /// Helper struct for visit_each_trackable().
-template <typename T_action>
+template<typename T_action>
 struct limit_trackable_target
 {
-  template <typename T_type>
+  template<typename T_type>
   void operator()(T_type&& type) const
   {
-    //Only call action_() if T_Type derives from trackable.
-    if constexpr(is_base_of_or_same_v<sigc::trackable, T_type>) {
-        std::invoke(action_, type);
+    // Only call action_() if T_Type derives from trackable.
+    if constexpr (is_base_of_or_same_v<sigc::trackable, T_type>)
+    {
+      std::invoke(action_, type);
+    }
+    else
+    {
+      // Prevent 'unreferenced formal parameter' warning from MSVC by 'using' type
+      static_cast<void>(type);
     }
   }
 
@@ -107,10 +111,10 @@ struct limit_trackable_target
  *
  * @ingroup sigcfunctors
  */
-template <typename T_functor>
+template<typename T_functor>
 struct visitor
 {
-  template <typename T_action>
+  template<typename T_action>
   static void do_visit_each(const T_action& action, const T_functor& functor)
   {
     action(functor);
@@ -121,7 +125,7 @@ struct visitor
  *
  * @ingroup sigcfunctors
  */
-template <typename T_action, typename T_functor>
+template<typename T_action, typename T_functor>
 void
 visit_each(const T_action& action, const T_functor& functor)
 {
@@ -143,7 +147,7 @@ visit_each(const T_action& action, const T_functor& functor)
  *
  * @ingroup sigcfunctors
  */
-template <typename T_action, typename T_functor>
+template<typename T_action, typename T_functor>
 void
 visit_each_trackable(const T_action& action, const T_functor& functor)
 {
