@@ -11,8 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * License along with this library; if not, see <https://www.gnu.org/licenses/>.
  */
 
 // Bug 564005 - Valgrind errors and crash on exit with Gtk::UIManager
@@ -197,7 +196,8 @@ private:
 // If it would come after them it wouldn't be inlined.
 
 template<typename T_CppObject>
-inline T_CppObject* RefPtr<T_CppObject>::operator->() const
+inline T_CppObject*
+RefPtr<T_CppObject>::operator->() const
 {
   return pCppObject_;
 }
