@@ -5,6 +5,7 @@
 #include "testutilities.h"
 #include <sigc++/trackable.h>
 #include <sigc++/signal.h>
+#include <memory>
 
 namespace
 {
@@ -49,7 +50,7 @@ void
 test_simple()
 {
   sigc::signal<int(int)> sig;
-  sig.connect(sigc::ptr_fun(&foo));
+  sig.connect([](int i) { return foo(i); });
 
   sig(1);
   util->check_result(result_stream, "foo(int 1) ");
@@ -62,27 +63,28 @@ bar(float i)
   return 1;
 }
 
+template<typename T_signal>
 void
 test_auto_disconnection()
 {
   // signal
-  sigc::signal<int(int)> sig;
+  T_signal sig;
 
   // connect some slots before emitting & test auto-disconnection
   {
     A a;
     sig.connect(sigc::ptr_fun(&foo));
-    sig.connect(sigc::mem_fun(a, &A::foo));
-    sig.connect(sigc::ptr_fun(&bar));
+    sig.connect_first(sigc::mem_fun(a, &A::foo));
+    sig.connect_first(sigc::ptr_fun(&bar));
     sig(1);
     result_stream << sig.size();
-    util->check_result(result_stream, "foo(int 1) A::foo(int 1) bar(float 1) 3");
+    util->check_result(result_stream, "bar(float 1) A::foo(int 1) foo(int 1) 3");
 
   } // a dies => auto-disconnect
 
   sig(2);
   result_stream << sig.size();
-  util->check_result(result_stream, "foo(int 2) bar(float 2) 2");
+  util->check_result(result_stream, "bar(float 2) foo(int 2) 2");
 }
 
 void
@@ -104,12 +106,23 @@ test_make_slot()
   // test make_slot()
   sigc::signal<int(int)> sig;
   sig.connect(sigc::ptr_fun(&foo));
-  sig.connect(sigc::ptr_fun(&bar));
+  sig.connect_first([](float i) { return bar(i); });
   sig.connect(sigc::ptr_fun(&foo));
   sigc::signal<int(int)> sig2;
   sig2.connect(sig.make_slot());
   sig2(3);
-  util->check_result(result_stream, "foo(int 3) bar(float 3) foo(int 3) ");
+  util->check_result(result_stream, "bar(float 3) foo(int 3) foo(int 3) ");
+
+  // Delete a trackable_signal that has been connected to sig2.
+  sig2.clear();
+  sig2.connect(sigc::ptr_fun(&bar));
+  auto sig3 = std::make_unique<sigc::trackable_signal<int(int)>>();
+  sig3->connect(sigc::ptr_fun(&foo));
+  sig2.connect(sig3->make_slot());
+  sig2(2);
+  sig3.reset();
+  sig2(42);
+  util->check_result(result_stream, "bar(float 2) foo(int 2) bar(float 42) ");
 }
 
 void
@@ -158,7 +171,8 @@ main(int argc, char* argv[])
 
   test_empty_signal();
   test_simple();
-  test_auto_disconnection();
+  test_auto_disconnection<sigc::signal<int(int)>>();
+  test_auto_disconnection<sigc::trackable_signal<int(int)>>();
   test_reference();
   test_make_slot();
   test_clear_called_in_signal_handler();
